<template>
  <el-dialog :visible.sync="isShow" :title="title" width="900px" :modal-append-to-body="false"
             :close-on-click-modal="false">
    <div class="confirmAllocation-style">
      <div class="padding-style">
        <span>总数量：</span>
        <span class="f-style">{{totalCount}}</span>
      </div>
      <list-condition-template ref="table1" :dataKey="'spuNum'" :tableData="tableData1"
                               :isShowPage="false">
        <template slot="columns">
          <el-table-column label="商品主编码" prop="spuNum" width="200px" show-overflow-tooltip>
          </el-table-column>
          <el-table-column label="产品名称" prop="spuName" min-width="200px" show-overflow-tooltip>
          </el-table-column>
          <el-table-column label="计量单位" prop="unit" width="120px"></el-table-column>
          <el-table-column label="分配数量" prop="stock" width="150px" show-overflow-tooltip>
          </el-table-column>
        </template>
      </list-condition-template>
      <div class="padding-style">
        <div style="margin-top:20px;">
          <span>当前分配设置：</span>
          <span>
            <span v-if="allotMode === 'AUTOMATIC'">比例分配</span>
            <span v-else-if="allotMode === 'MANUAL'">手动分配</span>
          </span>
          <span class="tips">（温馨提示：若要修改分配方式，请前往【分配设置】中进行调整）</span>
        </div>
      </div>
      <list-condition-template ref="table2" :dataKey="'id'" :tableData="tableData2" :total="total2"
                               :isShowPage="false" :indexColumn="false">
        <template slot="columns">
          <el-table-column label="渠道名称" prop="channelName" show-overflow-tooltip align="center">
          </el-table-column>
          <el-table-column label="分发比例（%）" align="center">
            <template slot-scope="scope">
              <span v-if="scope.row.ratio">{{scope.row.ratio}}%</span>
              <span v-else-if="scope.row.ratio === 0" class="disabled-style">0%</span>
            </template>
          </el-table-column>
        </template>
      </list-condition-template>
    </div>
    <div slot="footer" class="dialog-footer">
      <el-button size="mini" @click="confirmAllocation" type="primary" :loading="loading">确认分配
      </el-button>
      <el-button size="mini" @click="isShow = false">取消</el-button>
    </div>
  </el-dialog>
</template>

<script>
import commodityStocksApi from '@/api/stockManagement/commodityStocks'
import dictApi from '@/api/dict'
export default {
  name: "confirmAllocationDialog",
  props: {
    dialogVisible: {
      type: Boolean,
      default: false
    },
    title: {
      type: String,
      default: ''
    }
  },
  data() {
    return {
      isShow: false,
      totalCount: 0,//总数量
      total1: 0,
      tableData1: [],
      total2: 0,
      tableData2: [],
      allotMode: null,//分配方式
      loading: false,
    }
  },
  watch: {
    /**
     * 监控外部显示变量变化
     * 传递到dialog组件
     */
    dialogVisible: function (newShow, oldShow) {
      this.isShow = newShow
    },
    /**
     * 监控内部显示属性变化
     * 传递到外部调用变量
     */
    isShow: function (newDialogShow, oldDialogShow) {
      if (!newDialogShow) {
        this.$emit('update:dialogVisible', newDialogShow)
      }
    }
  },
  mounted() {
    this.initChannelData();
  },
  methods: {
    /**
    * 初始化渠道数据字典
    */
    async initChannelData() {
      const res = await dictApi.getChanneldict()
      let _data = res.data;
      if (res.code === '0' && _data && _data.length > 0) {
        let _arr = [];
        _data.forEach((item) => {
          _arr.push({
            id: item.dictCode,
            channelName: item.dictName,
            ratio: null,
          })
        })
        this.tableData2 = _arr;
      }
    },
    getInfo(_data) {
      let totalCount = 0;
      this.allotMode = _data.allotType;
      this.tableData1 = _data.rowItem;
      this.tableData1.forEach((item) => {
        totalCount += Number(item.stockTotal);
      })
      this.totalCount = totalCount;
      if (_data.data && _data.data.length > 0) {
        this.tableData2.forEach((v1) => {
          let _obj = _data.data.find((v2) => v1.id === v2.channel);
          if (_obj) {
            v1.ratio = _obj.ratio;
          }
        })
      }
    },
    async confirmAllocation() {
      let spus = [];
      this.tableData1.forEach((item) => {
        spus.push({
          distributeStock: item.stock,
          spuNum: item.spuNum
        })
      })
      let params = {
        spus: spus
      }
      this.loading = true;
      const res = await commodityStocksApi.confiemAllocation(params)
      if (res.code === '200') {
        this.$message({
          message: '分配成功',
          type: 'success'
        })
        this.$emit("close")
        this.loading = false;
        this.isShow = false;
      } else {
        this.loading = false;
      }
    }
  }
}
</script>

<style lang="scss">
.confirmAllocation-style {
  .main-b-style {
    padding: 0 20px !important;
  }
  .padding-style {
    padding: 0 20px;
  }
  .tips {
    color: rgb(144, 147, 153);
    font-size: 14px;
  }
  .disabled-style {
    color: #c0c4cc;
  }
  .f-style {
    font-weight: bold;
    color: #909399;
  }
}
</style>
